
/**
*  标签选择
*/

import React from 'react';
import { Text, TextStyle, TouchableOpacity, View, ViewStyle } from 'react-native';
import defaultStyle from '../../configs/defaultStyle';
import Icon from '../icon';


interface Props {

    /**
    *  样式
    */
    style?: ViewStyle,

    /**
    *  类型 slider：滑块   icon:图标
    */
    type?: 'slider' | 'icon'

    /**
    *  选择项,表示选择了第几项,传null表示什么都不选
    */
    index?: number

    /**
    *  tab 按钮
    */
    tabItems: { title: string, icon?: number, selectIcon?: number, iconStyle?: TextStyle }[]

    /**
    *  选择事件
    */
    onSelect: (index: number) => void;

}

export default function TabBar(props: Readonly<Props>) {

    return (
        <View style={{ height: 40, flexDirection: 'row', justifyContent: 'space-around', borderBottomColor: '#cccccc99', borderBottomWidth: 0.5, ...props.style }}>
            {
                props.tabItems.map((tab, i) => {
                    let select = (i == props.index)
                    if (props.type == 'slider') {
                        return (
                            <TouchableOpacity style={{ alignSelf: 'stretch', flex: 1 }} key={tab.title}
                                onPress={() => props.onSelect && props.onSelect(i)}>
                                <View style={{ flex: 1, justifyContent: 'center', alignItems: 'center' }}>
                                    <Text style={{ color: select ? defaultStyle.color.mainColor : 'rgba(0,0,0,0.8)', fontSize: 14, textAlign: 'center' }}>{tab.title}</Text>
                                </View>
                                <View style={{ height: 2, backgroundColor: select ? defaultStyle.color.mainColor : '#00000000' }} />
                            </TouchableOpacity>
                        )
                    } else {
                        return (
                            <TouchableOpacity style={{ flexDirection: 'row', alignSelf: 'stretch', alignItems: 'center', paddingHorizontal: 10 }} key={tab.title}
                                onPress={() => props.onSelect && props.onSelect(i)}>
                                <Text style={{ color: select ? defaultStyle.color.mainColor : 'rgba(0,0,0,0.8)', fontSize: 14 }}>{tab.title}</Text>
                                {
                                    tab.icon && <Icon style={{ color: select ? defaultStyle.color.mainColor : 'rgba(0,0,0,0.8)', fontSize: 8, marginLeft: 3, ...tab.iconStyle }}
                                        iconCode={select ? (tab.selectIcon || tab.icon) : tab.icon} />
                                }
                            </TouchableOpacity>
                        )
                    }
                })
            }
        </View >
    )

}
